@@ -61,13 +61,17 @@ class Firefox(
 
         # profile settings
         private: bool = False,
-        screen_size: Optional[Tuple[int, int]] = None, # (width, height)
         full_screen: bool = True,
-        headless: bool = False,
         language: str = 'en-us',
         user_agent: Optional[str] = None,
         disable_images: bool = False,
 
+        # firefox option settings
+        screen_size: Optional[Tuple[int, int]] = None, # (width, height)
+        headless: bool = False,
+        mute_audio: bool = False,
+        home_page_url: Optional[str] = None,
+
         # selenium-wire support
         webdriver_class: Optional = None,
 
@@ -113,7 +117,9 @@ class Firefox(
             ),
             firefox_options=Utils.options(
                 screen_size=screen_size,
-                headless=headless
+                headless=headless,
+                home_page_url=home_page_url,
+                mute_audio=mute_audio
             ),
             firefox_binary=FirefoxBinary(
                 firefox_path=firefox_binary_path
